Task query
----------

.. autosummary::
    :toctree: api/

    prismstudio.list_taskquery
    prismstudio.delete_taskquery
    prismstudio.load_taskquery
    prismstudio.save_taskquery
    prismstudio.rename_taskquery
    .. prismstudio.extract_taskquery
